``xp eval_klip``
================

Apply the KLIP+ADI algorithm of :doc:`klip` with fake planet injection and SNR measurement.

.. argparse::
    :ref: xpipeline.commands.eval_klip._docs_args
    :prog: xp eval_klip
    :passparser:
